@@ -3,14 +3,10 @@
 # pylint: disable=import-error
 # Import third-party modules
 from pkg_resources import DistributionNotFound, get_distribution
-from rayvision_log import init_logger
 
 # Import local modules
-from rayvision_sync.constants import PACKAGE_NAME
 from rayvision_sync.transfer import RayvisionTransfer
 
-# Initialize the logger.
-init_logger(PACKAGE_NAME)
 
 # All API of the public.
 __all__ = ['RayvisionTransfer']
