@@ -35,7 +35,7 @@ class RayvisionDownload(object):
     def __init__(self, api,
                  transports_json="",
                  transmitter_exe="",
-                 automatic_line=False,
+                 automatic_line=True,
                  internet_provider="",
                  logger=None,
                  log_folder=None,
@@ -48,7 +48,7 @@ class RayvisionDownload(object):
             api (object): rayvision api object.
             transports_json (string): Customize the absolute path of the transfer configuration file.
             transmitter_exe (string): Customize the absolute path of the transfer execution file.
-            automatic_line (bool): Whether to automatically obtain the transmission line, the default is "False"
+            automatic_line (bool): Whether to automatically obtain the transmission line, the default is "True"
             internet_provider (string): Network provider.
             logger (object): Customize log object.
             log_folder (string): Customize the absolute path of the folder where logs are stored.
@@ -68,7 +68,7 @@ class RayvisionDownload(object):
             init_logger(PACKAGE_NAME, log_folder, log_name)
             self.logger = logging.getLogger(__name__)
             self.logger.setLevel(level=log_level.upper())
-        self.raysync_engine = RayvisionTransferRaysync(self.trans.user_id, self.api.user_info.get("user_name"),
+        self.raysync_engine = RayvisionTransferRaysync(self.api.user_info.get("domain"), self.trans.user_id, self.api.user_info.get("user_name"),
                                                        self.api.query.get_raysync_user_key().get('raySyncUserKey'),
                                                        self.trans.platform, self.logger)
 
