@@ -34,9 +34,4 @@ RAYSYNCEXE = {
     "Linux": "Raysync-man"
 }
 
-DOWNLINK = {
-    "Windows": "https://task.renderbus.com/download/Raysync Client.zip",
-    "Linux": "https://task.renderbus.com/download/Raysync.zip"
-}
-
 STATU_SLEEP = 5
\ No newline at end of file
