@@ -88,6 +88,20 @@ def api(user_info_dict, mocker, tmpdir):
     """Create connect API object."""
     mocker_task_id = mocker.patch.object(Connect, "post")
     mocker_task_id.return_value = {}
+    return_value = {
+        "aspera": {
+            "server_name": "TEST_CTCC",
+            "server_ip": "45.251.92.29",
+            "server_port": "10221"
+        },
+        "raysync": {
+            "server_name": "TEST_CTCC",
+            "server_ip": "45.251.92.29",
+            "server_port": "10200"
+        }
+    }
+    mocker.patch('rayvision_sync.transfer.RayvisionTransfer.parse_service_transfe_line',
+                 return_value=return_value)
     rayvision_api = RayvisionAPI(**user_info_dict)
     if "win" in sys.platform.lower():
         local_os = "windows"
