@@ -200,7 +200,7 @@ class RayvisionTransfer(object):
                     ]
 
             db_ini_path (str): Database path.
-            engine_type (str, optional): set engine type, support "aspera" and "raysync", Default "aspera".
+            engine_type (str, optional): set engine type, support "aspera" and "raysyncweb", Default "aspera".
             server_ip (str, optional): transmit server host,
                 if not set, it is obtained from the default transport profile.
             server_port (str, optional): transmit server port,
@@ -223,7 +223,7 @@ class RayvisionTransfer(object):
             engine_type = "aspera"
         if engine_type not in ENGINE_TYPE:
             msg = "{} is not a supported transport engine, " \
-                  "currently only support 'aspera' and 'raysync'".format(engine_type)
+                  "currently only support 'aspera' and 'raysyncweb'".format(engine_type)
             raise UnsupportedEngineType(msg)
         transmit_cmd = ('echo y|"{exePath}" -E "{engineType}"'
                         ' -H "{serverIp}" -P "{serverPort}" -S "{download_id}"'
