@@ -37,7 +37,7 @@ class RayvisionUpload(object):
                  db_config_path=None,
                  transports_json="",
                  transmitter_exe="",
-                 automatic_line=False,
+                 automatic_line=True,
                  internet_provider="",
                  logger=None,
                  log_folder=None,
@@ -51,7 +51,7 @@ class RayvisionUpload(object):
             db_config_path (string): Customize db_config.ini absolute path.
             transports_json (string): Customize the absolute path of the transfer configuration file.
             transmitter_exe (string): Customize the absolute path of the transfer execution file.
-            automatic_line (bool): Whether to automatically obtain the transmission line, the default is "False"
+            automatic_line (bool): Whether to automatically obtain the transmission line, the default is "True"
             internet_provider (string): Network provider.
             logger (object): Customize log object.
             log_folder (string): Customize the absolute path of the folder where logs are stored.
@@ -71,7 +71,7 @@ class RayvisionUpload(object):
         params["internet_provider"] = internet_provider
         self.api = api
         self.trans = RayvisionTransfer(api, **params)
-        self.raysync_engine = RayvisionTransferRaysync(self.trans.user_id, self.api.user_info.get("user_name"),
+        self.raysync_engine = RayvisionTransferRaysync(self.api.user_info.get("domain"), self.trans.user_id, self.api.user_info.get("user_name"),
                                                        self.api.query.get_raysync_user_key().get('raySyncUserKey'),
                                                        self.trans.platform, self.logger)
 
